/*删除酒店数据库,如果存在*/
drop database if exists hotel;
/*创建数据库,并设置编码*/
create database hotel default character set utf8;

use hotel;

drop table if exists user;
/*删除客房类型表*/
drop table if exists roomcategory;
/*删除客房状态表*/
drop table if exists roomstate;
/*删除客房表*/
drop table if exists room;
/*删除顾客表*/
drop table if exists client;
/*删除业务表*/
drop table if exists business;

/*============================*/
/* Table: 用户表结构 		  */
/*============================*/
create table user
(
   /* 用户编号,自动增长 */
   uid                  int not null auto_increment,
   /* 用户登录名  */
   ulogin               varchar(20),
   /* 用户姓名  */
   uname                varchar(20),
   /* 用户密码 */
   upassword            varchar(20),
   /* 用户性别（0-男，1-女） */
   usex                 int,
   /* 用户电话 */
   uphone               varchar(20),
   /* 用户类型（0-客服，1-管理员）*/
   ucategory            int,
   /* 用户状态（0-未登录，1-登录）*/
   ustate               int,
   /* 设置编号为主键 */
   primary key (uid)
);
/*=============================*/
/* Table: 客房类型表结构 		   */
/*=============================*/
create table roomcategory
(
   /* 类型编号,自动增长 */
   rcid                  int not null auto_increment,
   /* 类型名称 */
   rcname                varchar(20),
   /* 此类客房价格 */
   rcprice               decimal(8,2),
   /* 配置床位 */
   rcnum                 int,
    /* 类型是否为热点类别*/
   rchot                 bool default false,
   /* 外键,此类型由哪位用户管理 */
   rcuid                 int,
   /* 设置类型编号为主键 */
   primary key (rcid)
);
/*=============================*/
/* Table: 客房状态表结构 		   */
/*=============================*/
create table roomstate
(
   /* 状态编号,自动增长 */
   rsid                  int not null auto_increment,
   /* 状态名称 */
   rsname                varchar(20),
   /* 设置状态编号为主键 */
   primary key (rsid)
);
/*=============================*/
/* Table: 客房表结构 		   */
/*=============================*/
create table room
(
   /* 客房编号,自动增长 */
   rid                   int not null auto_increment,
   /* 客房名称 */
   rname                 varchar(20),
   /* 外键,客房种类编号 */
   rrcid                 int,
   /*  外键,客房状态编号 */
   rrsid                 int,
   /*  外键,顾客编号 */
   rcid                  int,
    /* 入住日期*/
   rdate                 date,
   /* 预订天数*/
   rnumber               int,
   /* 押金 */
   rcash                 decimal(8,2),
   /* 总金额 */
   rfee                  decimal(8,2),
   /* 客房说明 */
   rremark               varchar(200),
   /* 外键,处理人*/
   ruid                  int,
   /* 设置客房编号为主键 */
   primary key (rid)
);
/*=============================*/
/* Table: 顾客表结构 		   */
/*=============================*/
create table client
(
   /* 顾客编号,自动增长 */
   cid                   int not null auto_increment,
   /* 顾客姓名 */
   cname                 varchar(20),
   /* 顾客身份证号码 */
   cidcard               varchar(18),
   /* 顾客电话 */
   cphone                varchar(20),
   /* 设置顾客编号为主键 */
   primary key (cid)
);
/*=============================*/
/* Table: 业务表结构 		   */
/*=============================*/
create table business
(
   /* 业务编号,自动增长 */
   bid                   int not null auto_increment,
   /* 业务名称*/
   bname                 varchar(20),
   /* 业务时间*/
   btime                 timestamp,
   /* 外键,客房编号 */
   brid                  int,
   /* 外键,种类编号 */
   brcid                 int,
   /* 外键,顾客编号 */
   bcid                  int,
   /* 入住时间*/
   bdate                 date,
   /* 入住天数*/
   bnumber               int,
   /* 押金 */
   bcash                 decimal(8,2),
   /* 总金额 */
   bfee                  decimal(8,2),
   /* 说明，业务描述*/
   bremark               varchar(200),
   /* 外键,处理人*/
   buid                  int,
   /* 设置业务编号为主键 */
   primary key (bid)
);
/* 用户测试用例 */
INSERT INTO user(ulogin,uname,upassword,usex,uphone,ucategory,ustate) values ('admin','管理员A','admin',0,'13576864367',1,0);
INSERT INTO user(ulogin,uname,upassword,usex,uphone,ucategory,ustate) values ('user','客服A','user',1,'13576864367',0,0);
/* 客房种类测试用例 */
INSERT INTO roomcategory(rcname,rcprice,rcnum,rchot,rcuid) values ('标准（单）间',198,1,true,1);
INSERT INTO roomcategory(rcname,rcprice,rcnum,rchot,rcuid) values ('标准（双）间',268,2,true,2);
INSERT INTO roomcategory(rcname,rcprice,rcnum,rchot,rcuid) values ('行政套房',398,2,false,1);
INSERT INTO roomcategory(rcname,rcprice,rcnum,rchot,rcuid) values ('豪华套房',598,2,false,1);
INSERT INTO roomcategory(rcname,rcprice,rcnum,rchot,rcuid) values ('大床房',288,1,true,2);
INSERT INTO roomcategory(rcname,rcprice,rcnum,rchot,rcuid) values ('特价房',128,1,true,2);
/* 客房状态测试用例 */
INSERT INTO roomstate(rsname) values ('空');
INSERT INTO roomstate(rsname) values ('已预订');
INSERT INTO roomstate(rsname) values ('已入住');
/* 客房测试用例 */
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8801',1,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8802',1,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8803',1,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8804',1,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8805',1,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8806',2,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8807',2,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8808',2,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8809',2,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8810',2,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8811',3,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8812',3,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8813',3,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8814',3,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8815',3,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8816',4,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8817',4,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8818',4,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8819',4,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8820',4,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8821',5,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8822',5,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8823',5,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8824',5,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8825',5,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8826',6,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8827',6,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8828',6,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8829',6,1,"此房间光线较好");
INSERT INTO room(rname,rrcid,rrsid,rremark) values ('8830',6,1,"此房间光线较好");
/* 顾客测试用例 */
INSERT INTO client(cname,cidcard,cphone) values ('李明','422202199408042345','15627382738');

SELECT * FROM user;
SELECT * FROM roomcategory;
SELECT * FROM roomstate;
SELECT * FROM room;
SELECT * FROM client;
SELECT * FROM business;
SELECT bname,sum(bnumber) FROM business group by brcid;
SELECT DATE_FORMAT(b.btime,'%Y-%m-%d'),sum(b.bfee) FROM Business b WHERE b.bname='开房'or b.bname='入住' GROUP BY DATE_FORMAT(b.btime,'%Y-%m-%d');